@@ -38,15 +38,17 @@ INTERFACE_TYPE_MAP = {'SCSI': INTERFACE_TYPE_SCSI,
                       'SAS': INTERFACE_TYPE_SAS,
                       'SATA': INTERFACE_TYPE_SATA,
                       'SATASSD': INTERFACE_TYPE_SATA,
-                      'SASSSD': INTERFACE_TYPE_SAS}
+                      'SASSSD': INTERFACE_TYPE_SAS,
+                      'Solid State SAS': INTERFACE_TYPE_SAS}
 
 DISK_TYPE_MAP = {'SCSI': DISK_TYPE_HDD,
                  'SAS': DISK_TYPE_HDD,
                  'SATA': DISK_TYPE_HDD,
                  'SATASSD': DISK_TYPE_SSD,
-                 'SASSSD': DISK_TYPE_SSD}
+                 'SASSSD': DISK_TYPE_SSD,
+                 'Solid State SAS': DISK_TYPE_SSD}
 
-RAID_LEVEL_MIN_DISKS = {RAID_0: 2,
+RAID_LEVEL_MIN_DISKS = {RAID_0: 1,
                         RAID_1: 2,
                         RAID_1_ADM: 3,
                         RAID_5: 3,
@@ -56,6 +58,9 @@ RAID_LEVEL_MIN_DISKS = {RAID_0: 2,
                         RAID_60: 8}
 
 
+MINIMUM_DISK_SIZE = 1
+
+
 def get_interface_type(ssa_interface):
     return INTERFACE_TYPE_MAP[ssa_interface]
 
