@@ -16,7 +16,9 @@
 """Test class for RIBCL Module."""
 
 import json
+import re
 import unittest
+import xml.etree.ElementTree as ET
 
 import mock
 import requests
@@ -595,6 +597,50 @@ class IloRibclTestCase(unittest.TestCase):
         self.assertIsInstance(ilo_firmware, dict)
         self.assertEqual(expected_ilo, ilo_firmware)
 
+    @mock.patch.object(ribcl.RIBCLOperations, 'get_host_health_data')
+    def test_get_ilo_firmware_version_as_major_minor(self, mock_health_data):
+        data = constants.GET_EMBEDDED_HEALTH_OUTPUT
+        mock_health_data.return_value = json.loads(data)
+        expected_ilo = '2.02'
+        ilo_firmware = self.ilo.get_ilo_firmware_version_as_major_minor()
+        self.assertEqual(expected_ilo, ilo_firmware)
+
+    @mock.patch.object(ribcl.RIBCLOperations, 'get_host_health_data')
+    def test_get_ilo_firmware_version_as_major_minor_eq_suggested(
+            self, mock_health_data):
+        data = constants.GET_EMBEDDED_HEALTH_OUTPUT_EQ_SUGGESTED
+        mock_health_data.return_value = json.loads(data)
+        expected_ilo = '2.30'
+        ilo_firmware = self.ilo.get_ilo_firmware_version_as_major_minor()
+        self.assertEqual(expected_ilo, ilo_firmware)
+
+    @mock.patch.object(ribcl.RIBCLOperations, 'get_host_health_data')
+    def test_get_ilo_firmware_version_as_major_minor_gt_suggested(
+            self, mock_health_data):
+        data = constants.GET_EMBEDDED_HEALTH_OUTPUT_GT_SUGGESTED
+        mock_health_data.return_value = json.loads(data)
+        expected_ilo = '2.54'
+        ilo_firmware = self.ilo.get_ilo_firmware_version_as_major_minor()
+        self.assertEqual(expected_ilo, ilo_firmware)
+
+    @mock.patch.object(ribcl.RIBCLOperations, 'get_host_health_data')
+    def test_get_ilo_firmware_version_as_major_minor_unexpected(
+            self, mock_health_data):
+        data = constants.GET_EMBEDDED_HEALTH_OUTPUT_UNEXPECTED_FORMAT
+        mock_health_data.return_value = json.loads(data)
+        expected_ilo = None
+        ilo_firmware = self.ilo.get_ilo_firmware_version_as_major_minor()
+        self.assertEqual(expected_ilo, ilo_firmware)
+
+    @mock.patch.object(ribcl.RIBCLOperations, 'get_host_health_data')
+    def test_get_ilo_firmware_version_as_major_minor_no_firmware(
+            self, mock_health_data):
+        data = constants.GET_EMBEDDED_HEALTH_OUTPUT_NO_FIRMWARE
+        mock_health_data.return_value = json.loads(data)
+        expected_ilo = None
+        ilo_firmware = self.ilo.get_ilo_firmware_version_as_major_minor()
+        self.assertEqual(expected_ilo, ilo_firmware)
+
     def test__get_number_of_gpu_devices_connected(self):
         data = constants.GET_EMBEDDED_HEALTH_OUTPUT
         json_data = json.loads(data)
@@ -707,6 +753,80 @@ class IloRibclTestCase(unittest.TestCase):
         self.assertRaises(exception.IloError, self.ilo.activate_license, 'key')
         self.assertTrue(request_mock.called)
 
+    @mock.patch.object(
+        ribcl.firmware_controller.FirmwareImageUploader, 'upload_file_to')
+    @mock.patch.object(ribcl, 'os', autospec=True)
+    @mock.patch.object(ribcl.IloClient, '_request_ilo', autospec=True)
+    @mock.patch.object(ribcl.IloClient, '_parse_output', autospec=True)
+    @mock.patch.object(common, 'wait_for_ribcl_firmware_update_to_complete',
+                       lambda x: None)
+    def test_update_ilo_firmware(self, _parse_output_mock, _request_ilo_mock,
+                                 os_mock, upload_file_to_mock):
+        # | GIVEN |
+        upload_file_to_mock.return_value = 'hickory-dickory-dock'
+        os_mock.path.getsize.return_value = 12345
+        # | WHEN |
+        self.ilo.update_firmware('raw_fw_file.bin', 'ilo')
+        # | THEN |
+        upload_file_to_mock.assert_called_once_with(
+            (self.ilo.host, self.ilo.port), self.ilo.timeout)
+
+        root_xml_string = constants.UPDATE_ILO_FIRMWARE_INPUT_XML % (
+            self.ilo.password, self.ilo.login, 12345, 'raw_fw_file.bin')
+        root_xml_string = re.sub('\n\s*', '', root_xml_string)
+
+        ((ribcl_obj, xml_elem), the_ext_header_dict) = (
+            _request_ilo_mock.call_args)
+
+        self.assertEqual(root_xml_string,
+                         ET.tostring(xml_elem).decode('latin-1'))
+        self.assertDictEqual(the_ext_header_dict['extra_headers'],
+                             {'Cookie': 'hickory-dickory-dock'})
+
+        _parse_output_mock.assert_called_once_with(
+            self.ilo, _request_ilo_mock.return_value)
+
+    @mock.patch.object(
+        ribcl.firmware_controller.FirmwareImageUploader, 'upload_file_to')
+    @mock.patch.object(ribcl, 'os', autospec=True)
+    @mock.patch.object(ribcl.IloClient, '_request_ilo', autospec=True)
+    @mock.patch.object(ribcl.IloClient, '_parse_output', autospec=True)
+    @mock.patch.object(common, 'wait_for_ribcl_firmware_update_to_complete',
+                       lambda x: None)
+    def test_update_other_component_firmware(self, _parse_output_mock,
+                                             _request_ilo_mock, os_mock,
+                                             upload_file_to_mock):
+        # | GIVEN |
+        upload_file_to_mock.return_value = 'hickory-dickory-dock'
+        os_mock.path.getsize.return_value = 12345
+        # | WHEN |
+        self.ilo.update_firmware('raw_fw_file.bin', 'power_pic')
+        # | THEN |
+        upload_file_to_mock.assert_called_once_with(
+            (self.ilo.host, self.ilo.port), self.ilo.timeout)
+
+        root_xml_string = constants.UPDATE_NONILO_FIRMWARE_INPUT_XML % (
+            self.ilo.password, self.ilo.login, 12345, 'raw_fw_file.bin')
+        root_xml_string = re.sub('\n\s*', '', root_xml_string)
+
+        ((ribcl_obj, xml_elem), the_ext_header_dict) = (
+            _request_ilo_mock.call_args)
+
+        self.assertEqual(root_xml_string,
+                         ET.tostring(xml_elem).decode('latin-1'))
+        self.assertDictEqual(the_ext_header_dict['extra_headers'],
+                             {'Cookie': 'hickory-dickory-dock'})
+
+        _parse_output_mock.assert_called_once_with(
+            self.ilo, _request_ilo_mock.return_value)
+
+    def test_update_firmware_throws_error_for_invalid_component(self):
+        # | WHEN | & | THEN |
+        self.assertRaises(exception.InvalidInputError,
+                          self.ilo.update_firmware,
+                          'raw_fw_file.bin',
+                          'invalid_component')
+
 
 class IloRibclTestCaseBeforeRisSupport(unittest.TestCase):
 
